@@ -161,15 +161,15 @@ class ViewContainer(Gtk.Stack):
         if button.get_active():
             self.view.set_selection_mode(True)
             self.header_bar.set_selection_mode(True)
-            self.player.eventBox.set_visible(False)
-            self.selection_toolbar.eventbox.set_visible(True)
+            self.player.actionbar.set_visible(False)
+            self.selection_toolbar.actionbar.set_visible(True)
             self.selection_toolbar._add_to_playlist_button.set_sensitive(False)
             self.selection_toolbar._remove_from_playlist_button.set_sensitive(False)
         else:
             self.view.set_selection_mode(False)
             self.header_bar.set_selection_mode(False)
-            self.player.eventBox.set_visible(self.player.currentTrack is not None)
-            self.selection_toolbar.eventbox.set_visible(False)
+            self.player.actionbar.set_visible(self.player.currentTrack is not None)
+            self.selection_toolbar.actionbar.set_visible(False)
 
     @log
     def _on_cancel_button_clicked(self, button):
@@ -1200,6 +1200,8 @@ class Search(ViewContainer):
     @log
     def __init__(self, window, player):
         ViewContainer.__init__(self, 'search', None, window, Gd.MainViewType.LIST)
+        self.view.set_halign(Gtk.Align.CENTER)
+        self.view.set_size_request(530, -1)
         self._items = {}
         self.isStarred = None
         self.iter_to_clean = None
@@ -1389,7 +1391,7 @@ class Search(ViewContainer):
 
     @log
     def populate(self):
-        pass
+        self.header_bar.set_state(ToolbarState.MAIN)
 
     @log
     def get_selected_tracks(self, callback):
