@@ -237,17 +237,17 @@ class AlbumWidget(Gtk.EventBox):
         if button.get_active():
             self.view.set_selection_mode(True)
             self.header_bar.set_selection_mode(True)
-            self.player.eventBox.set_visible(False)
-            self.selection_toolbar.eventbox.set_visible(True)
+            self.player.actionbar.set_visible(False)
+            self.selection_toolbar.actionbar.set_visible(True)
             self.selection_toolbar._add_to_playlist_button.set_sensitive(False)
             self.header_bar.header_bar.set_custom_title(self.header_bar._selection_menu_button)
         else:
             self.view.set_selection_mode(False)
             self.header_bar.set_selection_mode(False)
             self.header_bar.title = self.album
-            self.selection_toolbar.eventbox.set_visible(False)
+            self.selection_toolbar.actionbar.set_visible(False)
             if(self.player.get_playback_status() != 2):
-                self.player.eventBox.set_visible(True)
+                self.player.actionbar.set_visible(True)
 
     @log
     def _on_discovered(self, info, error, _iter):
@@ -270,7 +270,7 @@ class AlbumWidget(Gtk.EventBox):
                             '', '', None, track, NOW_PLAYING_ICON_NAME,
                             False])
             self.ui.get_object('running_length_label_info').set_text(
-                '%d min' % (int(self.duration / 60) + 1))
+                _("%d min") % (int(self.duration / 60) + 1))
 
     @log
     def _on_look_up(self, pixbuf, path, data=None):
@@ -308,7 +308,7 @@ class AlbumWidget(Gtk.EventBox):
                 playlist.set_value(_iter, 9, iconVisible)
             _iter = playlist.iter_next(_iter)
             self.ui.get_object('running_length_label_info').set_text(
-                '%d min' % (int(self.duration / 60) + 1))
+                _("%d min") % (int(self.duration / 60) + 1))
         return False
 
 
